package com.hungraim.ltc.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ism.pojo.vo.disable.DisableEvaluateInfoVO;
import com.hungraim.ism.pojo.vo.disable.DisableEvaluateVO;
import com.hungraim.ltc.pojo.entity.disable.ChDisableEvaluate;
import com.hungraim.ltc.service.DisableEvaluateService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 失能评定Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.apply/disableEvaluate")
@Slf4j
public class DisableEvaluateController {

    @Autowired
    private DisableEvaluateService disableEvaluateService;

    /**
     * 失能评定列表
     *
     * @param organId    适用机构代码
     * @param srvOrganId 护理机构
     * @param realName   失能人员姓名
     * @param certiCode  失能人员身份证号码
     * @param pageNum    当前页
     * @param pageSize   每页几条数据
     * @return 失能评定列表
     */
    @RequestMapping("/disableEvaluateList")
    public Result<List<DisableEvaluateVO>> disableEvaluateList(String organId, String srvOrganId, String realName, String certiCode, int pageNum, int pageSize) {
        IPage<DisableEvaluateVO> iPage = disableEvaluateService.disableEvaluateList(organId, realName, certiCode, srvOrganId, pageNum, pageSize);
        return Result.success(iPage.getRecords());
    }

    /**
     * 失能评定详情
     *
     * @param evaluateId 评定id
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableEvaluateInfo")
    public Result<DisableEvaluateInfoVO> disableEvaluateInfo(String evaluateId) {
        DisableEvaluateInfoVO disableEvaluateInfoVO = disableEvaluateService.disableEvaluateInfo(evaluateId);
        return Result.success(disableEvaluateInfoVO);
    }

    /**
     * 失能评定
     *
     * @param applyId     申请id
     * @param checkName   审核人
     * @param applyStatus 审核结果
     * @param checkRemark 审核备注
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableEvaluate")
    public Result disableEvaluate(String applyId, String checkName, Short applyStatus, String checkRemark) {
        //disableEvaluateService.disableExamine(applyId, checkName, applyStatus, checkRemark);
        return Result.success();
    }

    /**
     * 新增失能申请
     */
    @RequestMapping("/addDisableEvaluate")
    public Result addEvaluate(ChDisableEvaluate chDisableEvaluate) {
        return Result.success();
    }

}
